var structjs_consumer_info =
[
    [ "Stream", "structjs_consumer_info.html#a8f21939613163a7c0ebfb521aa471260", null ],
    [ "Name", "structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008", null ],
    [ "Created", "structjs_consumer_info.html#a670d38f2e9ba5c354ca3560a8064d00c", null ],
    [ "Config", "structjs_consumer_info.html#a2f63940ca1f024ad3840418c2f6a1ae1", null ],
    [ "Delivered", "structjs_consumer_info.html#a15f2d68fbf126acc1907ba9462ad9ee9", null ],
    [ "AckFloor", "structjs_consumer_info.html#ab69c36ae092df9b0663b675a5abbab55", null ],
    [ "NumAckPending", "structjs_consumer_info.html#a882bebeb7af80fcce088afdf2c98de50", null ],
    [ "NumRedelivered", "structjs_consumer_info.html#a932bf14ebb9ce167af8975e3b1f8d001", null ],
    [ "NumWaiting", "structjs_consumer_info.html#a57e4a4139310c50a1f3d51af67197af0", null ],
    [ "NumPending", "structjs_consumer_info.html#aeaefd5a500996013b1ce13d8872e869b", null ],
    [ "Cluster", "structjs_consumer_info.html#a6f4401563a9fd102226d82cdc6136e32", null ],
    [ "PushBound", "structjs_consumer_info.html#a31282cdc72000a91af03f89899740bfa", null ],
    [ "Paused", "structjs_consumer_info.html#a13f80f4b24da173ef2da051e69f216d7", null ],
    [ "PauseRemaining", "structjs_consumer_info.html#a86501e735531929add3e161d40479c44", null ],
    [ "PriorityGroups", "structjs_consumer_info.html#a1b93a87ac24c171319a7d8350355c1ef", null ],
    [ "PriorityGroupsLen", "structjs_consumer_info.html#a5deb4de557d4520772ef6a1319c7e67c", null ]
];